% Copyright (c) Yuting Zhang
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.

function DATA = zjugaitacc_all( data_dir )
% Read all data record from ZJU-GaitAcc dataset
% Version 1.0.0
% Usage:
%    (1) DATA = zjugaitacc_read
%    (2) DATA = zjugaitacc_read( data_dir )
% When data_dir is not specified, the folder where this function located is
%   considered to be the data folder.
%
% Copyright (c) Yuting Zhang, 2014
% http://www.ytzhang.net/datasets/zju-gaitacc

if ~exist( 'data_dir', 'var' ) || isempty(data_dir)
    data_dir = fileparts( mfilename('fullpath') );
end

DATA.SESSION0 = zjugaitacc_session(0, data_dir);
DATA.SESSION1 = zjugaitacc_session(1, data_dir);
DATA.SESSION2 = zjugaitacc_session(2, data_dir);

end

function SDATA = zjugaitacc_session( session_id, data_dir )

numRecord = 6;
re_file = fullfile(data_dir,'record_total.txt');
if exist( re_file, 'file' )
    numRecord = dlmread(re_file);
end

subj_file = fullfile(data_dir,sprintf('session_%d/total.txt',session_id));
numSubj = dlmread(subj_file);

SDATA = repmat( struct('data',[],'cycles',[],'useful',[]), ...
    numRecord, numSubj );

for s = 1:numSubj
    for r = 1:numRecord
        SDATA(r,s) = zjugaitacc_read( session_id, s, r, data_dir );
    end
end

end

