% Copyright (c) Yuting Zhang
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.

function rec = zjugaitacc_read( session_id, subj_id, record_id, data_dir )
% Read data record from ZJU-GaitAcc dataset
% Version 1.0.0
% Usage:
%    (1) rec = zjugaitacc_read( session_id, subj_id, record_id )
%    (2) ... = zjugaitacc_read( ..., data_dir )
% When data_dir is not specified, the folder where this function located is
%   considered to be the data folder.
%
% Copyright (c) Yuting Zhang, 2014
% http://www.ytzhang.net/datasets/zju-gaitacc

if ~exist( 'data_dir', 'var' ) || isempty(data_dir)
    data_dir = fileparts( mfilename('fullpath') );
end

numChannels = 5;
ch_file = fullfile(data_dir,'channel_total.txt');
if exist( ch_file, 'file' )
    numChannels = dlmread(ch_file);
end

record_folder = sprintf( '%s/session_%d/subj_%03d/rec_%d', ...
    data_dir, session_id, subj_id, record_id);

rec = struct( 'data', [], 'cycles', [], 'useful', [] );

c_file     = fullfile( record_folder, 'cycles.txt' );
rec.cycles = dlmread( c_file );
u_file     = fullfile( record_folder, 'useful.txt' );
rec.useful = dlmread( u_file );

rec.data = cell(1,1,numChannels);

for c = 1:numChannels
    s_file = fullfile( record_folder, sprintf('%d.txt',c) );
    rec.data{c} = dlmread( s_file );
end
rec.data = cell2mat(rec.data);

end
